<?php
// An example of using xAuth to get an Access Token

// Load the library
require_once('tumblroauth/tumblroauth.php');

// Define the needed keys
$consumer_key = "YOUR CONSUMER KEY GOES HERE";
$consumer_secret = "PUT THE SECRET KEY HERE";

// When using xAuth, you ask the user for their username and password, versus sending them
// to Tumblr and letting Tumblr ask them.  You then trade their username and password for an Access
// Token which is usef from then on.  You should never store the user's username and password.  Use it only
// to get an Access Token and store that instead.

// If you're familiar with the traditional OAuth flow, understand that with xAuth you skip the Request Token
// and Authorize (Sending the user to Tumblr) steps.  You go directly to Access Token.

// Create instance of TumblrOAuth.
// It'll need our Consumer Key and Secret.
$tum_oauth = new TumblrOAuth($consumer_key, $consumer_secret);

// This script will get the user's username and password through a GET/POST request.
$username = $_REQUEST['username'];
$password = $_REQUEST['password'];

// Ok, let's get an Access Token. We'll need to pass along the user's username and password.
$access_token = $tum_oauth->getXAuthToken($username, $password);

// Make sure nothing went wrong.
if (200 == $tum_oauth->http_code) {
  // good to go
} else {
  die('Unable to authenticate');
}

// What's next?  Now that we have an Access Token and Secret, we can make an API call.

// Any API call that requires OAuth authentiation will need the info we have now - (Consumer Key,
// Consumer Secret, Access Token, and Access Token secret).

// You should store the Access Token and Secret in a database, or if you must, a Cookie in the user's browser.
// Never expose your Consumer Secret.  It should stay on your server, avoid storing it in code viewable to the user.

// I'll make the /user/info API call to get some baisc information about the user

// Start a new instance of TumblrOAuth, overwriting the old one.
// This time it will need our Access Token and Secret instead of our Request Token and Secret
$tum_oauth = new TumblrOAuth($consumer_key, $consumer_secret, $access_token['oauth_token'], $access_token['oauth_token_secret']);

// Make an API call with the TumblrOAuth instance.  There's also a post and delete method too.
$userinfo = $tum_oauth->get('http://api.tumblr.com/v2/user/info');

// You don't actuall have to pass a full URL,  TukmblrOAuth will complete the URL for you.
// This will also work: $userinfo = $tum_oauth->get('user/info');

// Check for an error.
if (200 == $tum_oauth->http_code) {
  // good to go
} else {
  die('Unable to get info');
}

// find primary blog.  Display its name.
$screen_name = $userinfo->response->user->name;
for ($fln=0; $fln<count($userinfo->response->user->blogs); $fln=$fln+1) {
	if ($userinfo->response->user->blogs[$fln]->primary==true) {
		echo("Your primary blog's name: " .($userinfo->response->user->blogs[$fln]->title));
		break;
	}
}

echo("<br/>");
echo("Your user name (the part before tumblr.com of your primary blog): ".$userinfo->response->user->name);

// And that's that.  Hopefully it will help.
?>
